@@ -1,4 +1,6 @@
+"""Contains code pertaining to the fetching, inserting and deleting of entities into/from repositories."""
 from __future__ import annotations
+
 from collections.abc import MutableMapping
 from typing import TYPE_CHECKING, Dict, Iterator
 
@@ -9,30 +11,33 @@ if TYPE_CHECKING:
     from .repository import Entity, TransferEntity
 
 
-class Contents(MutableMapping, Base):
+class Contents(MutableMapping, Base):  # pylint: disable=too-many-ancestors
+    """Handles the fetching, inserting and deleting of entities into/from repositories."""
+
     def __init__(self, entities: Dict[str, Entity], gateway: AbstractGateway) -> None:
+        """Initialize the contents."""
         self.entities = entities
         self.gateway = gateway
 
     def __getitem__(self, identifier: str) -> TransferEntity:
-        """Fetches an entity."""
+        """Fetch an entity."""
         entity = self.entities[identifier]
         return entity.create_transfer_entity(self.gateway.fetch(identifier))
 
     def __setitem__(self, identifier: str, transfer_entity: TransferEntity) -> None:
-        """Inserts an entity."""
+        """Insert an entity."""
         self.gateway.insert(transfer_entity.data)
         self.entities[identifier] = transfer_entity.create_entity()
 
     def __delitem__(self, identifier: str) -> None:
-        """Deletes an entity."""
+        """Delete an entity."""
         self.gateway.delete(identifier)
         del self.entities[identifier]
 
     def __iter__(self) -> Iterator[str]:
-        """Iterates over entity identifiers."""
+        """Iterate over entity identifiers."""
         return iter(self.entities)
 
     def __len__(self) -> int:
-        """Returns the number of entities in the repository."""
+        """Return the number of entities in the repository."""
         return len(self.entities)
