@@ -1,6 +1,8 @@
+"""Contains code handling transactions in repositories."""
 from __future__ import annotations
-from typing import TYPE_CHECKING, Dict, Iterator, Optional
+
 from contextlib import contextmanager
+from typing import TYPE_CHECKING, Dict, Iterator
 
 from ..base import Base
 from .abstract_gateway import AbstractGateway
@@ -10,28 +12,31 @@ if TYPE_CHECKING:
 
 
 class TransactionManager(Base):
+    """Handles the starting, committing and cancelling of transactions in a repository."""
+
     def __init__(self, entities: Dict[str, Entity], gateway: AbstractGateway) -> None:
+        """Initialize the transaction manager."""
         self.entities = entities
         self.gateway = gateway
         self._entities_copy: Dict[str, Entity]
 
     @property
     def in_transaction(self) -> bool:
-        """Returns "True" if the manager is in transaction, "False" otherwise."""
+        """Return "True" if the manager is in transaction, "False" otherwise."""
         return hasattr(self, "_entities_copy")
 
     def start(self) -> None:
-        """Starts a transaction."""
+        """Start a transaction."""
         self.gateway.start_transaction()
         setattr(self, "_entities_copy", self.entities.copy())
 
     def commit(self) -> None:
-        """Commits a transaction."""
+        """Commit a transaction."""
         self.gateway.commit_transaction()
         delattr(self, "_entities_copy")
 
     def cancel(self) -> None:
-        """Cancels a transaction."""
+        """Cancel a transaction."""
         self.entities.update(self._entities_copy)
         self.gateway.cancel_transaction()
         delattr(self, "_entities_copy")
