@@ -1,14 +1,15 @@
+"""Contains DataJoint helper functions."""
 import re
 import warnings
-from typing import Dict, Type, Optional, Collection
 from inspect import isclass
+from typing import Collection, Dict, Optional, Type
 
 from datajoint import Part
 from datajoint.user_tables import UserTable
 
 
 def replace_stores(definition: str, stores: Dict[str, str]) -> str:
-    """Replaces the stores in the definition according to a mapping of replacement to original stores."""
+    """Replace the store in the definition according to a mapping of replacement to original stores."""
     stores = {original: replacement for replacement, original in stores.items()}
 
     def replace_store(match):
@@ -25,6 +26,7 @@ def replace_stores(definition: str, stores: Dict[str, str]) -> str:
 def get_part_table_classes(
     table_cls: Type[UserTable], ignored_parts: Optional[Collection[str]] = None
 ) -> Dict[str, Type[Part]]:
+    """Return all part table classes found on the provided table class."""
     if ignored_parts is None:
         ignored_parts = []
     part_table_classes = {}
