@@ -1,3 +1,4 @@
+"""Contains code pertaining to the handling of files."""
 from contextlib import AbstractContextManager
 from tempfile import TemporaryDirectory
 
@@ -10,19 +11,21 @@ class ReusableTemporaryDirectory(AbstractContextManager, Base):
     temp_dir_cls = TemporaryDirectory
 
     def __init__(self, prefix: str) -> None:
+        """Initialize the reusable temporary directory."""
         self.prefix = prefix
         self._temp_dir: TemporaryDirectory
 
     def __enter__(self) -> str:
-        """Returns the name of a newly created temporary directory."""
+        """Return the name of a newly created temporary directory."""
         self._temp_dir = self.temp_dir_cls(prefix=self.prefix)
         return self.name
 
     def __exit__(self, exc_type, exc_val, exc_tb) -> None:
-        """Cleans up the temporary directory created by entering the with clause."""
+        """Clean up the temporary directory created by entering the with clause."""
         self._temp_dir.cleanup()
         del self._temp_dir
 
     @property
     def name(self) -> str:
+        """Return the name of the temporary directory."""
         return self._temp_dir.name
