@@ -1,6 +1,8 @@
+"""Contains code pertaining to the refresh use-case."""
 from __future__ import annotations
-from typing import TYPE_CHECKING, Set
+
 from dataclasses import dataclass
+from typing import TYPE_CHECKING, Set
 
 from .base import AbstractRequestModel, AbstractResponseModel, AbstractUseCase
 
@@ -21,14 +23,19 @@ class RefreshResponseModel(AbstractResponseModel):
 
     @property
     def n_refreshed(self) -> int:
+        """Return the number of entities that were refreshed."""
         return len(self.refreshed)
 
 
-class RefreshUseCase(AbstractUseCase[RefreshRequestModel]):
+class RefreshUseCase(
+    AbstractUseCase[RefreshRequestModel]
+):  # pylint: disable=unsubscriptable-object,too-few-public-methods
+    """Use-case that refreshes entities in the local table."""
+
     response_model_cls = RefreshResponseModel
 
-    def execute(self, repo_link: RepositoryLink, request_model: RefreshRequestModel) -> RefreshResponseModel:
-        """Refreshes the deletion requested flags in the local table."""
+    def execute(self, repo_link: RepositoryLink, _: RefreshRequestModel) -> RefreshResponseModel:
+        """Refresh the deletion requested flags in the local table."""
         deletion_requested = {i for i in repo_link.outbound if repo_link.outbound.flags[i]["deletion_requested"]}
         to_be_enabled = {i for i in deletion_requested if not repo_link.local.flags[i]["deletion_requested"]}
         for identifier in to_be_enabled:
